@@ -1,2 +1,2 @@
-(use-modules (aiscm magick) (aiscm rgb) (aiscm jit))
+(use-modules (aiscm magick) (aiscm core))
 (write-image (% (read-image "star-ferry.jpg") (rgb 250 200 150)) "modulo.jpg")
