@@ -788,10 +788,10 @@
   (for-each (lambda (op a b result)
     (test-eqv (format #f "(~a 2 3) should be ~a" (procedure-name op) result)
       result ((jit (list <int> <int>) op) a b)))
-    (list +  - * <<  % & |)
-    '(    2  2 2  2 13 3 3)
-    '(    3  3 3  3  5 5 5)
-    '(    5 -1 6 16  3 1 7))
+    (list +  - * <<  % & | ^)
+    '(    2  2 2  2 13 3 3 5)
+    '(    3  3 3  3  5 5 5 4)
+    '(    5 -1 6 16  3 1 7 1))
   (test-eqv "Unsigned integer division"
     127 ((jit (list <ubyte> <ubyte>) /) 254 2))
   (test-eqv "Signed integer division"
@@ -1435,7 +1435,7 @@
   (test-equal "upcast result type for RGB values"
     (rgb 256 256 256) (sum (to-array (list (rgb 255 255 255) (rgb 1 1 1)))))
   (test-eqv "product of 1D array"
-    30 (prod (arr 2 3 5)))
+    30 (product (arr 2 3 5)))
   (test-eqv "Minimum of array"
     2 (min (arr 2 3 5)))
   (test-eqv "Maximum of array"
@@ -1563,7 +1563,9 @@
   (test-approximate "Arc tangent of two double-precision floating point numbers"
     2.356 (car (to-list (atan (arr <double> 1.0) (arr <double> -1.0)))) 0.001)
   (test-approximate "Arc tangent of single- and double-precision floating point number"
-    2.356 (car (to-list (atan (arr <float> 1.0) (arr <double> -1.0)))) 0.001) )
+    2.356 (car (to-list (atan (arr <float> 1.0) (arr <double> -1.0)))) 0.001)
+  (test-approximate "Exponentiation"
+    2.718 (car (to-list (exp (arr <float> 1.0)))) 0.001))
 
 (test-group "phi values"
   (test-eqv "Try phi function"
@@ -1654,13 +1656,13 @@
 
 (test-group "index arrays"
   (test-equal "shape of index array"
-    '(2 3 5) (shape (index 2 3 5)))
+    '(2 3 5) (shape (indices 2 3 5)))
   (test-equal "indices in 1D array"
-    '(0 1 2) (to-list (index 3)))
+    '(0 1 2) (to-list (indices 3)))
   (test-equal "2D index array"
-    '((0 1 2) (3 4 5)) (to-list (index 3 2))))
+    '((0 1 2) (3 4 5)) (to-list (indices 3 2))))
 
-(test-group "Comparison"
+(test-group "comparison"
   (test-assert "equal arrays"
     (equal? (arr 2 3 5) (arr 2 3 5)))
   (test-assert "differing shape"
@@ -1668,4 +1670,26 @@
   (test-assert "different elements"
     (not (equal? (arr 2 3 5) (arr 2 4 5)))))
 
+(test-group "warps"
+  (test-equal "trivial 1D warp"
+    '(2 3 5) (to-list (warp (arr 2 3 5) (arr 0 1 2))))
+  (test-equal "mirroring 1D warp"
+    '(5 3 2) (to-list (warp (arr 2 3 5) (arr 2 1 0))))
+  (test-equal "use strides of source array"
+    '(2 3 5) (to-list (warp (arr <int> 2 3 5) (arr 0 1 2))))
+  (test-equal "use strides of index array"
+    '(2 3 5) (to-list (warp (arr 2 3 5) (arr <int> 0 1 2))))
+  (test-equal "use shape of index array"
+    '(2 3) (to-list (warp (arr 2 3 5) (arr 0 1))))
+  (test-equal "warp with two index arrays"
+    '(2 3 13) (to-list (warp (arr (2 3 5) (7 11 13)) (arr 0 1 2) (arr 0 0 1))))
+  (test-equal "warp with 2D result"
+    '((2 3 5) (13 11 7)) (to-list (warp (arr 2 3 5 7 11 13) (arr (0 1 2) (5 4 3)))))
+  (test-equal "warp with 2D and 1D index array"
+    '((13 13 13)) (to-list (warp (arr (2 3 5) (7 11 13)) (arr 2) (arr (1 1 1)))))
+  (test-equal "warp with 1D and 2D index array"
+    '((13 13 13)) (to-list (warp (arr (2 3 5) (7 11 13)) (arr (2 2 2)) (arr 1))))
+  (test-equal "warp with arrays as elements"
+    '((11 13) (2 3) (5 7)) (to-list (warp (arr (2 3) (5 7) (11 13)) (arr 2 0 1)))))
+
 (test-end "aiscm core")
